# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_gamenotifications.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_gamenotifications.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%steammessages_gamenotifications.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\xe0\x02\n\x1b\x43GameNotifications_Variable\x12\xa6\x01\n\x03key\x18\x01 \x01(\tB\x98\x01\x82\xb5\x18\x93\x01The name of the variable in the localized text -- anywhere that %variablename% is found within the text it will be substituded with the given value\x12\x97\x01\n\x05value\x18\x02 \x01(\tB\x87\x01\x82\xb5\x18\x82\x01The value of the variable to substitute in the localized text in place of the given variable.  Can itself be a localization token.\"\x85\x03\n CGameNotifications_LocalizedText\x12H\n\x05token\x18\x01 \x01(\tB9\x82\xb5\x18\x35\x41 localization token that maps to the desired string.\x12\x8d\x01\n\tvariables\x18\x02 \x03(\x0b\x32\x1c.CGameNotifications_VariableB\\\x82\xb5\x18XA list of variables values to substitute in any variables found in the localized string.\x12\x86\x01\n\rrendered_text\x18\x03 \x01(\tBo\x82\xb5\x18kText rendered in the requested language, complete with variable substitutions, if a language was specified.\"\x95\x04\n\x1d\x43GameNotifications_UserStatus\x12\x31\n\x07steamid\x18\x01 \x01(\x06\x42 \x82\xb5\x18\x1cThe specific user\'s steamid.\x12\xa4\x01\n\x05state\x18\x02 \x01(\tB\x94\x01\x82\xb5\x18\x8f\x01The user\'s state.  ready -- the user is ready to play.  waiting -- The game is waiting on an action from the user. completed, the game is over.\x12\x84\x01\n\x05title\x18\x03 \x01(\x0b\x32!.CGameNotifications_LocalizedTextBR\x82\xb5\x18NTitle of the session to display to this user in their list of active sessions.\x12\x92\x01\n\x07message\x18\x04 \x01(\x0b\x32!.CGameNotifications_LocalizedTextB^\x82\xb5\x18ZSubtitle of the session to display to this user user within their list of active sessions.\"\x93\x05\n(CGameNotifications_CreateSession_Request\x12\x37\n\x05\x61ppid\x18\x01 \x01(\rB(\x82\xb5\x18$The appid to create the session for.\x12\x7f\n\x07\x63ontext\x18\x02 \x01(\x04\x42n\x82\xb5\x18jGame-specified context value the game can used to associate the session with some object on their backend.\x12\x83\x01\n\x05title\x18\x03 \x01(\x0b\x32!.CGameNotifications_LocalizedTextBQ\x82\xb5\x18MThe title of the session to be displayed within each user\'s list of sessions.\x12\x61\n\x05users\x18\x04 \x03(\x0b\x32\x1e.CGameNotifications_UserStatusB2\x82\xb5\x18.The initial state of all users in the session.\x12\xc3\x01\n\x07steamid\x18\x05 \x01(\x06\x42\xb1\x01\x82\xb5\x18\xac\x01(Optional) steamid to make the request on behalf of -- if specified, the user must be in the session and all users being added to the session must be friends with the user.\"i\n)CGameNotifications_CreateSession_Response\x12<\n\tsessionid\x18\x01 \x01(\x04\x42)\x82\xb5\x18%The sessionid of the created session.\"\x8f\x02\n(CGameNotifications_DeleteSession_Request\x12/\n\tsessionid\x18\x01 \x01(\x04\x42\x1c\x82\xb5\x18\x18The sessionid to delete.\x12\x36\n\x05\x61ppid\x18\x02 \x01(\rB\'\x82\xb5\x18#The appid of the session to delete.\x12z\n\x07steamid\x18\x03 \x01(\x06\x42i\x82\xb5\x18\x65(Optional) steamid to make the request on behalf of -- if specified, the user must be in the session.\"+\n)CGameNotifications_DeleteSession_Response\"\xbd\x05\n(CGameNotifications_UpdateSession_Request\x12/\n\tsessionid\x18\x01 \x01(\x04\x42\x1c\x82\xb5\x18\x18The sessionid to update.\x12\x36\n\x05\x61ppid\x18\x02 \x01(\rB\'\x82\xb5\x18#The appid of the session to update.\x12\x90\x01\n\x05title\x18\x03 \x01(\x0b\x32!.CGameNotifications_LocalizedTextB^\x82\xb5\x18Z(Optional) The new title of the session.  If not specified, the title will not be changed.\x12\xce\x01\n\x05users\x18\x04 \x03(\x0b\x32\x1e.CGameNotifications_UserStatusB\x9e\x01\x82\xb5\x18\x99\x01(Optional) A list of users whose state will be updated to reflect the given state. If the users are not already in the session, they will be added to it.\x12\xc3\x01\n\x07steamid\x18\x06 \x01(\x06\x42\xb1\x01\x82\xb5\x18\xac\x01(Optional) steamid to make the request on behalf of -- if specified, the user must be in the session and all users being added to the session must be friends with the user.\"+\n)CGameNotifications_UpdateSession_Response\"\xa1\x04\n,CGameNotifications_EnumerateSessions_Request\x12~\n\x05\x61ppid\x18\x01 \x01(\rBo\x82\xb5\x18kThe sessionid to request details for. Optional. If not specified, all the user\'s sessions will be returned.\x12\x8e\x01\n\x19include_all_user_messages\x18\x03 \x01(\x08\x42k\x82\xb5\x18g(Optional) Boolean determining whether the message for all users should be included. Defaults to false.\x12\x9b\x01\n\x19include_auth_user_message\x18\x04 \x01(\x08\x42x\x82\xb5\x18t(Optional) Boolean determining whether the message for the authenticated user should be included. Defaults to false.\x12\x42\n\x08language\x18\x05 \x01(\tB0\x82\xb5\x18,(Optional) Language to localize the text in.\"\xc3\x04\n\x1a\x43GameNotifications_Session\x12\x36\n\tsessionid\x18\x01 \x01(\x04\x42#\x82\xb5\x18\x1fThe sessionid for this session.\x12-\n\x05\x61ppid\x18\x02 \x01(\x04\x42\x1e\x82\xb5\x18\x1aThe appid for the session.\x12\x7f\n\x07\x63ontext\x18\x03 \x01(\x04\x42n\x82\xb5\x18jGame-specified context value the game can used to associate the session with some object on their backend.\x12X\n\x05title\x18\x04 \x01(\x0b\x32!.CGameNotifications_LocalizedTextB&\x82\xb5\x18\"The current title for the session.\x12;\n\x0ctime_created\x18\x05 \x01(\rB%\x82\xb5\x18!The time the session was created.\x12@\n\x0ctime_updated\x18\x06 \x01(\rB*\x82\xb5\x18&The last time the session was updated.\x12\x64\n\x0buser_status\x18\x07 \x03(\x0b\x32\x1e.CGameNotifications_UserStatusB/\x82\xb5\x18+The status of all the users in the session.\"\x82\x01\n-CGameNotifications_EnumerateSessions_Response\x12Q\n\x08sessions\x18\x01 \x03(\x0b\x32\x1b.CGameNotifications_SessionB\"\x82\xb5\x18\x1e\x41 list of the user\'s sessions.\"\xd6\x03\n,CGameNotifications_GetSessionDetails_Request\x12P\n\x08sessions\x18\x01 \x03(\x0b\x32>.CGameNotifications_GetSessionDetails_Request.RequestedSession\x12.\n\x05\x61ppid\x18\x02 \x01(\rB\x1f\x82\xb5\x18\x1bThe appid for the sessions.\x12\x37\n\x08language\x18\x03 \x01(\tB%\x82\xb5\x18!Language to localize the text in.\x1a\xea\x01\n\x10RequestedSession\x12\x38\n\tsessionid\x18\x01 \x01(\x04\x42%\x82\xb5\x18!The sessionid to get details for.\x12\x9b\x01\n\x19include_auth_user_message\x18\x03 \x01(\x08\x42x\x82\xb5\x18t(Optional) Boolean determining whether the message for the authenticated user should be included. Defaults to false.\"\x7f\n-CGameNotifications_GetSessionDetails_Response\x12N\n\x08sessions\x18\x01 \x03(\x0b\x32\x1b.CGameNotifications_SessionB\x1f\x82\xb5\x18\x1bThe details of the session.\"\xa8\x01\n\x18GameNotificationSettings\x12\x37\n\x05\x61ppid\x18\x01 \x01(\rB(\x82\xb5\x18$The appid to create the session for.\x12S\n\x13\x61llow_notifications\x18\x02 \x01(\x08\x42\x36\x82\xb5\x18\x32Whether the user allows notification for this app.\"v\n5CGameNotifications_UpdateNotificationSettings_Request\x12=\n\x1agame_notification_settings\x18\x01 \x03(\x0b\x32\x19.GameNotificationSettings\"8\n6CGameNotifications_UpdateNotificationSettings_Response\"\xc6\x01\n8CGameNotifications_OnNotificationsRequested_Notification\x12N\n\x07steamid\x18\x01 \x01(\x06\x42=\x82\xb5\x18\x39steamid of the user who notifications were requested for.\x12:\n\x05\x61ppid\x18\x02 \x01(\rB+\x82\xb5\x18\'The appid that requested notifications.\"\xbe\x03\n3CGameNotifications_OnUserStatusChanged_Notification\x12>\n\x07steamid\x18\x01 \x01(\x06\x42-\x82\xb5\x18)steamid of the user whose status changed.\x12X\n\tsessionid\x18\x02 \x01(\x04\x42\x45\x82\xb5\x18\x41The sessionid of the session where the user\'s status was changed.\x12L\n\x05\x61ppid\x18\x03 \x01(\rB=\x82\xb5\x18\x39The appid of the session where the user\'s status changed.\x12V\n\x06status\x18\x04 \x01(\x0b\x32\x1e.CGameNotifications_UserStatusB&\x82\xb5\x18\"(Optional) New status of the user.\x12G\n\x07removed\x18\x05 \x01(\x08\x42\x36\x82\xb5\x18\x32(Optional) User has been removed from the session.2\xa6\x08\n\x11GameNotifications\x12\x8d\x01\n\x11UserCreateSession\x12).CGameNotifications_CreateSession_Request\x1a*.CGameNotifications_CreateSession_Response\"!\x82\xb5\x18\x1d\x43reates an async game session\x12\x8d\x01\n\x11UserDeleteSession\x12).CGameNotifications_DeleteSession_Request\x1a*.CGameNotifications_DeleteSession_Response\"!\x82\xb5\x18\x1d\x44\x65letes an async game session\x12\x8d\x01\n\x11UserUpdateSession\x12).CGameNotifications_UpdateSession_Request\x1a*.CGameNotifications_UpdateSession_Response\"!\x82\xb5\x18\x1dUpdates an async game session\x12\x94\x01\n\x11\x45numerateSessions\x12-.CGameNotifications_EnumerateSessions_Request\x1a..CGameNotifications_EnumerateSessions_Response\" \x82\xb5\x18\x1c\x45numerates a user\'s sessions\x12\x9e\x01\n\x11GetSessionDetails\x12-.CGameNotifications_GetSessionDetails_Request\x1a..CGameNotifications_GetSessionDetails_Response\"*\x82\xb5\x18&Get the details for a specific session\x12\xd6\x01\n\x1aUpdateNotificationSettings\x12\x36.CGameNotifications_UpdateNotificationSettings_Request\x1a\x37.CGameNotifications_UpdateNotificationSettings_Response\"G\x82\xb5\x18\x43Updates whether a user allows game notifications for a specific app\x1aP\x82\xb5\x18LA service for functions related to the asyncronous game notification server.2\xdf\x02\n\x17GameNotificationsClient\x12\x95\x01\n\x18OnNotificationsRequested\x12\x39.CGameNotifications_OnNotificationsRequested_Notification\x1a\x0b.NoResponse\"1\x82\xb5\x18-Requests that the user opt into notifications\x12\x8d\x01\n\x13OnUserStatusChanged\x12\x34.CGameNotifications_OnUserStatusChanged_Notification\x1a\x0b.NoResponse\"3\x82\xb5\x18/Notification that the user\'s status has changed\x1a\x1c\x82\xb5\x18\x14\x43lient notifications\xc0\xb5\x18\x02\x42\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CGAMENOTIFICATIONS_VARIABLE = _descriptor.Descriptor(
  name='CGameNotifications_Variable',
  full_name='CGameNotifications_Variable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='CGameNotifications_Variable.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\223\001The name of the variable in the localized text -- anywhere that %variablename% is found within the text it will be substituded with the given value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='CGameNotifications_Variable.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\202\001The value of the variable to substitute in the localized text in place of the given variable.  Can itself be a localization token.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=102,
  serialized_end=454,
)


_CGAMENOTIFICATIONS_LOCALIZEDTEXT = _descriptor.Descriptor(
  name='CGameNotifications_LocalizedText',
  full_name='CGameNotifications_LocalizedText',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='CGameNotifications_LocalizedText.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0305A localization token that maps to the desired string.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variables', full_name='CGameNotifications_LocalizedText.variables', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030XA list of variables values to substitute in any variables found in the localized string.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rendered_text', full_name='CGameNotifications_LocalizedText.rendered_text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030kText rendered in the requested language, complete with variable substitutions, if a language was specified.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=457,
  serialized_end=846,
)


_CGAMENOTIFICATIONS_USERSTATUS = _descriptor.Descriptor(
  name='CGameNotifications_UserStatus',
  full_name='CGameNotifications_UserStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CGameNotifications_UserStatus.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\034The specific user\'s steamid.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='CGameNotifications_UserStatus.state', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\217\001The user\'s state.  ready -- the user is ready to play.  waiting -- The game is waiting on an action from the user. completed, the game is over.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='CGameNotifications_UserStatus.title', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030NTitle of the session to display to this user in their list of active sessions.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='CGameNotifications_UserStatus.message', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030ZSubtitle of the session to display to this user user within their list of active sessions.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=849,
  serialized_end=1382,
)


_CGAMENOTIFICATIONS_CREATESESSION_REQUEST = _descriptor.Descriptor(
  name='CGameNotifications_CreateSession_Request',
  full_name='CGameNotifications_CreateSession_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CGameNotifications_CreateSession_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030$The appid to create the session for.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='context', full_name='CGameNotifications_CreateSession_Request.context', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030jGame-specified context value the game can used to associate the session with some object on their backend.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='CGameNotifications_CreateSession_Request.title', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030MThe title of the session to be displayed within each user\'s list of sessions.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users', full_name='CGameNotifications_CreateSession_Request.users', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030.The initial state of all users in the session.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CGameNotifications_CreateSession_Request.steamid', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\254\001(Optional) steamid to make the request on behalf of -- if specified, the user must be in the session and all users being added to the session must be friends with the user.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1385,
  serialized_end=2044,
)


_CGAMENOTIFICATIONS_CREATESESSION_RESPONSE = _descriptor.Descriptor(
  name='CGameNotifications_CreateSession_Response',
  full_name='CGameNotifications_CreateSession_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionid', full_name='CGameNotifications_CreateSession_Response.sessionid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030%The sessionid of the created session.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2046,
  serialized_end=2151,
)


_CGAMENOTIFICATIONS_DELETESESSION_REQUEST = _descriptor.Descriptor(
  name='CGameNotifications_DeleteSession_Request',
  full_name='CGameNotifications_DeleteSession_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionid', full_name='CGameNotifications_DeleteSession_Request.sessionid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\030The sessionid to delete.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CGameNotifications_DeleteSession_Request.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030#The appid of the session to delete.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CGameNotifications_DeleteSession_Request.steamid', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030e(Optional) steamid to make the request on behalf of -- if specified, the user must be in the session.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2154,
  serialized_end=2425,
)


_CGAMENOTIFICATIONS_DELETESESSION_RESPONSE = _descriptor.Descriptor(
  name='CGameNotifications_DeleteSession_Response',
  full_name='CGameNotifications_DeleteSession_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2427,
  serialized_end=2470,
)


_CGAMENOTIFICATIONS_UPDATESESSION_REQUEST = _descriptor.Descriptor(
  name='CGameNotifications_UpdateSession_Request',
  full_name='CGameNotifications_UpdateSession_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionid', full_name='CGameNotifications_UpdateSession_Request.sessionid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\030The sessionid to update.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CGameNotifications_UpdateSession_Request.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030#The appid of the session to update.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='CGameNotifications_UpdateSession_Request.title', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030Z(Optional) The new title of the session.  If not specified, the title will not be changed.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users', full_name='CGameNotifications_UpdateSession_Request.users', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\231\001(Optional) A list of users whose state will be updated to reflect the given state. If the users are not already in the session, they will be added to it.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CGameNotifications_UpdateSession_Request.steamid', index=4,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\254\001(Optional) steamid to make the request on behalf of -- if specified, the user must be in the session and all users being added to the session must be friends with the user.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2473,
  serialized_end=3174,
)


_CGAMENOTIFICATIONS_UPDATESESSION_RESPONSE = _descriptor.Descriptor(
  name='CGameNotifications_UpdateSession_Response',
  full_name='CGameNotifications_UpdateSession_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3176,
  serialized_end=3219,
)


_CGAMENOTIFICATIONS_ENUMERATESESSIONS_REQUEST = _descriptor.Descriptor(
  name='CGameNotifications_EnumerateSessions_Request',
  full_name='CGameNotifications_EnumerateSessions_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CGameNotifications_EnumerateSessions_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030kThe sessionid to request details for. Optional. If not specified, all the user\'s sessions will be returned.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_all_user_messages', full_name='CGameNotifications_EnumerateSessions_Request.include_all_user_messages', index=1,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030g(Optional) Boolean determining whether the message for all users should be included. Defaults to false.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_auth_user_message', full_name='CGameNotifications_EnumerateSessions_Request.include_auth_user_message', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030t(Optional) Boolean determining whether the message for the authenticated user should be included. Defaults to false.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CGameNotifications_EnumerateSessions_Request.language', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030,(Optional) Language to localize the text in.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3222,
  serialized_end=3767,
)


_CGAMENOTIFICATIONS_SESSION = _descriptor.Descriptor(
  name='CGameNotifications_Session',
  full_name='CGameNotifications_Session',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionid', full_name='CGameNotifications_Session.sessionid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\037The sessionid for this session.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CGameNotifications_Session.appid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\032The appid for the session.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='context', full_name='CGameNotifications_Session.context', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030jGame-specified context value the game can used to associate the session with some object on their backend.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='CGameNotifications_Session.title', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\"The current title for the session.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_created', full_name='CGameNotifications_Session.time_created', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030!The time the session was created.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_updated', full_name='CGameNotifications_Session.time_updated', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030&The last time the session was updated.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_status', full_name='CGameNotifications_Session.user_status', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030+The status of all the users in the session.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3770,
  serialized_end=4349,
)


_CGAMENOTIFICATIONS_ENUMERATESESSIONS_RESPONSE = _descriptor.Descriptor(
  name='CGameNotifications_EnumerateSessions_Response',
  full_name='CGameNotifications_EnumerateSessions_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessions', full_name='CGameNotifications_EnumerateSessions_Response.sessions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\036A list of the user\'s sessions.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4352,
  serialized_end=4482,
)


_CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST_REQUESTEDSESSION = _descriptor.Descriptor(
  name='RequestedSession',
  full_name='CGameNotifications_GetSessionDetails_Request.RequestedSession',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionid', full_name='CGameNotifications_GetSessionDetails_Request.RequestedSession.sessionid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030!The sessionid to get details for.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_auth_user_message', full_name='CGameNotifications_GetSessionDetails_Request.RequestedSession.include_auth_user_message', index=1,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030t(Optional) Boolean determining whether the message for the authenticated user should be included. Defaults to false.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4721,
  serialized_end=4955,
)

_CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST = _descriptor.Descriptor(
  name='CGameNotifications_GetSessionDetails_Request',
  full_name='CGameNotifications_GetSessionDetails_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessions', full_name='CGameNotifications_GetSessionDetails_Request.sessions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CGameNotifications_GetSessionDetails_Request.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\033The appid for the sessions.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CGameNotifications_GetSessionDetails_Request.language', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030!Language to localize the text in.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST_REQUESTEDSESSION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4485,
  serialized_end=4955,
)


_CGAMENOTIFICATIONS_GETSESSIONDETAILS_RESPONSE = _descriptor.Descriptor(
  name='CGameNotifications_GetSessionDetails_Response',
  full_name='CGameNotifications_GetSessionDetails_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessions', full_name='CGameNotifications_GetSessionDetails_Response.sessions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\033The details of the session.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4957,
  serialized_end=5084,
)


_GAMENOTIFICATIONSETTINGS = _descriptor.Descriptor(
  name='GameNotificationSettings',
  full_name='GameNotificationSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='GameNotificationSettings.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030$The appid to create the session for.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_notifications', full_name='GameNotificationSettings.allow_notifications', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0302Whether the user allows notification for this app.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5087,
  serialized_end=5255,
)


_CGAMENOTIFICATIONS_UPDATENOTIFICATIONSETTINGS_REQUEST = _descriptor.Descriptor(
  name='CGameNotifications_UpdateNotificationSettings_Request',
  full_name='CGameNotifications_UpdateNotificationSettings_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_notification_settings', full_name='CGameNotifications_UpdateNotificationSettings_Request.game_notification_settings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5257,
  serialized_end=5375,
)


_CGAMENOTIFICATIONS_UPDATENOTIFICATIONSETTINGS_RESPONSE = _descriptor.Descriptor(
  name='CGameNotifications_UpdateNotificationSettings_Response',
  full_name='CGameNotifications_UpdateNotificationSettings_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5377,
  serialized_end=5433,
)


_CGAMENOTIFICATIONS_ONNOTIFICATIONSREQUESTED_NOTIFICATION = _descriptor.Descriptor(
  name='CGameNotifications_OnNotificationsRequested_Notification',
  full_name='CGameNotifications_OnNotificationsRequested_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CGameNotifications_OnNotificationsRequested_Notification.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0309steamid of the user who notifications were requested for.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CGameNotifications_OnNotificationsRequested_Notification.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\'The appid that requested notifications.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5436,
  serialized_end=5634,
)


_CGAMENOTIFICATIONS_ONUSERSTATUSCHANGED_NOTIFICATION = _descriptor.Descriptor(
  name='CGameNotifications_OnUserStatusChanged_Notification',
  full_name='CGameNotifications_OnUserStatusChanged_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CGameNotifications_OnUserStatusChanged_Notification.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)steamid of the user whose status changed.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessionid', full_name='CGameNotifications_OnUserStatusChanged_Notification.sessionid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030AThe sessionid of the session where the user\'s status was changed.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CGameNotifications_OnUserStatusChanged_Notification.appid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0309The appid of the session where the user\'s status changed.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='CGameNotifications_OnUserStatusChanged_Notification.status', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\"(Optional) New status of the user.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='removed', full_name='CGameNotifications_OnUserStatusChanged_Notification.removed', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0302(Optional) User has been removed from the session.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5637,
  serialized_end=6083,
)

_CGAMENOTIFICATIONS_LOCALIZEDTEXT.fields_by_name['variables'].message_type = _CGAMENOTIFICATIONS_VARIABLE
_CGAMENOTIFICATIONS_USERSTATUS.fields_by_name['title'].message_type = _CGAMENOTIFICATIONS_LOCALIZEDTEXT
_CGAMENOTIFICATIONS_USERSTATUS.fields_by_name['message'].message_type = _CGAMENOTIFICATIONS_LOCALIZEDTEXT
_CGAMENOTIFICATIONS_CREATESESSION_REQUEST.fields_by_name['title'].message_type = _CGAMENOTIFICATIONS_LOCALIZEDTEXT
_CGAMENOTIFICATIONS_CREATESESSION_REQUEST.fields_by_name['users'].message_type = _CGAMENOTIFICATIONS_USERSTATUS
_CGAMENOTIFICATIONS_UPDATESESSION_REQUEST.fields_by_name['title'].message_type = _CGAMENOTIFICATIONS_LOCALIZEDTEXT
_CGAMENOTIFICATIONS_UPDATESESSION_REQUEST.fields_by_name['users'].message_type = _CGAMENOTIFICATIONS_USERSTATUS
_CGAMENOTIFICATIONS_SESSION.fields_by_name['title'].message_type = _CGAMENOTIFICATIONS_LOCALIZEDTEXT
_CGAMENOTIFICATIONS_SESSION.fields_by_name['user_status'].message_type = _CGAMENOTIFICATIONS_USERSTATUS
_CGAMENOTIFICATIONS_ENUMERATESESSIONS_RESPONSE.fields_by_name['sessions'].message_type = _CGAMENOTIFICATIONS_SESSION
_CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST_REQUESTEDSESSION.containing_type = _CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST
_CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST.fields_by_name['sessions'].message_type = _CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST_REQUESTEDSESSION
_CGAMENOTIFICATIONS_GETSESSIONDETAILS_RESPONSE.fields_by_name['sessions'].message_type = _CGAMENOTIFICATIONS_SESSION
_CGAMENOTIFICATIONS_UPDATENOTIFICATIONSETTINGS_REQUEST.fields_by_name['game_notification_settings'].message_type = _GAMENOTIFICATIONSETTINGS
_CGAMENOTIFICATIONS_ONUSERSTATUSCHANGED_NOTIFICATION.fields_by_name['status'].message_type = _CGAMENOTIFICATIONS_USERSTATUS
DESCRIPTOR.message_types_by_name['CGameNotifications_Variable'] = _CGAMENOTIFICATIONS_VARIABLE
DESCRIPTOR.message_types_by_name['CGameNotifications_LocalizedText'] = _CGAMENOTIFICATIONS_LOCALIZEDTEXT
DESCRIPTOR.message_types_by_name['CGameNotifications_UserStatus'] = _CGAMENOTIFICATIONS_USERSTATUS
DESCRIPTOR.message_types_by_name['CGameNotifications_CreateSession_Request'] = _CGAMENOTIFICATIONS_CREATESESSION_REQUEST
DESCRIPTOR.message_types_by_name['CGameNotifications_CreateSession_Response'] = _CGAMENOTIFICATIONS_CREATESESSION_RESPONSE
DESCRIPTOR.message_types_by_name['CGameNotifications_DeleteSession_Request'] = _CGAMENOTIFICATIONS_DELETESESSION_REQUEST
DESCRIPTOR.message_types_by_name['CGameNotifications_DeleteSession_Response'] = _CGAMENOTIFICATIONS_DELETESESSION_RESPONSE
DESCRIPTOR.message_types_by_name['CGameNotifications_UpdateSession_Request'] = _CGAMENOTIFICATIONS_UPDATESESSION_REQUEST
DESCRIPTOR.message_types_by_name['CGameNotifications_UpdateSession_Response'] = _CGAMENOTIFICATIONS_UPDATESESSION_RESPONSE
DESCRIPTOR.message_types_by_name['CGameNotifications_EnumerateSessions_Request'] = _CGAMENOTIFICATIONS_ENUMERATESESSIONS_REQUEST
DESCRIPTOR.message_types_by_name['CGameNotifications_Session'] = _CGAMENOTIFICATIONS_SESSION
DESCRIPTOR.message_types_by_name['CGameNotifications_EnumerateSessions_Response'] = _CGAMENOTIFICATIONS_ENUMERATESESSIONS_RESPONSE
DESCRIPTOR.message_types_by_name['CGameNotifications_GetSessionDetails_Request'] = _CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST
DESCRIPTOR.message_types_by_name['CGameNotifications_GetSessionDetails_Response'] = _CGAMENOTIFICATIONS_GETSESSIONDETAILS_RESPONSE
DESCRIPTOR.message_types_by_name['GameNotificationSettings'] = _GAMENOTIFICATIONSETTINGS
DESCRIPTOR.message_types_by_name['CGameNotifications_UpdateNotificationSettings_Request'] = _CGAMENOTIFICATIONS_UPDATENOTIFICATIONSETTINGS_REQUEST
DESCRIPTOR.message_types_by_name['CGameNotifications_UpdateNotificationSettings_Response'] = _CGAMENOTIFICATIONS_UPDATENOTIFICATIONSETTINGS_RESPONSE
DESCRIPTOR.message_types_by_name['CGameNotifications_OnNotificationsRequested_Notification'] = _CGAMENOTIFICATIONS_ONNOTIFICATIONSREQUESTED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CGameNotifications_OnUserStatusChanged_Notification'] = _CGAMENOTIFICATIONS_ONUSERSTATUSCHANGED_NOTIFICATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CGameNotifications_Variable = _reflection.GeneratedProtocolMessageType('CGameNotifications_Variable', (_message.Message,), {
  'DESCRIPTOR' : _CGAMENOTIFICATIONS_VARIABLE,
  '__module__' : 'steammessages_gamenotifications_pb2'
  # @@protoc_insertion_point(class_scope:CGameNotifications_Variable)
  })
_sym_db.RegisterMessage(CGameNotifications_Variable)

CGameNotifications_LocalizedText = _reflection.GeneratedProtocolMessageType('CGameNotifications_LocalizedText', (_message.Message,), {
  'DESCRIPTOR' : _CGAMENOTIFICATIONS_LOCALIZEDTEXT,
  '__module__' : 'steammessages_gamenotifications_pb2'
  # @@protoc_insertion_point(class_scope:CGameNotifications_LocalizedText)
  })
_sym_db.RegisterMessage(CGameNotifications_LocalizedText)

CGameNotifications_UserStatus = _reflection.GeneratedProtocolMessageType('CGameNotifications_UserStatus', (_message.Message,), {
  'DESCRIPTOR' : _CGAMENOTIFICATIONS_USERSTATUS,
  '__module__' : 'steammessages_gamenotifications_pb2'
  # @@protoc_insertion_point(class_scope:CGameNotifications_UserStatus)
  })
_sym_db.RegisterMessage(CGameNotifications_UserStatus)

CGameNotifications_CreateSession_Request = _reflection.GeneratedProtocolMessageType('CGameNotifications_CreateSession_Request', (_message.Message,), {
  'DESCRIPTOR' : _CGAMENOTIFICATIONS_CREATESESSION_REQUEST,
  '__module__' : 'steammessages_gamenotifications_pb2'
  # @@protoc_insertion_point(class_scope:CGameNotifications_CreateSession_Request)
  })
_sym_db.RegisterMessage(CGameNotifications_CreateSession_Request)

CGameNotifications_CreateSession_Response = _reflection.GeneratedProtocolMessageType('CGameNotifications_CreateSession_Response', (_message.Message,), {
  'DESCRIPTOR' : _CGAMENOTIFICATIONS_CREATESESSION_RESPONSE,
  '__module__' : 'steammessages_gamenotifications_pb2'
  # @@protoc_insertion_point(class_scope:CGameNotifications_CreateSession_Response)
  })
_sym_db.RegisterMessage(CGameNotifications_CreateSession_Response)

CGameNotifications_DeleteSession_Request = _reflection.GeneratedProtocolMessageType('CGameNotifications_DeleteSession_Request', (_message.Message,), {
  'DESCRIPTOR' : _CGAMENOTIFICATIONS_DELETESESSION_REQUEST,
  '__module__' : 'steammessages_gamenotifications_pb2'
  # @@protoc_insertion_point(class_scope:CGameNotifications_DeleteSession_Request)
  })
_sym_db.RegisterMessage(CGameNotifications_DeleteSession_Request)

CGameNotifications_DeleteSession_Response = _reflection.GeneratedProtocolMessageType('CGameNotifications_DeleteSession_Response', (_message.Message,), {
  'DESCRIPTOR' : _CGAMENOTIFICATIONS_DELETESESSION_RESPONSE,
  '__module__' : 'steammessages_gamenotifications_pb2'
  # @@protoc_insertion_point(class_scope:CGameNotifications_DeleteSession_Response)
  })
_sym_db.RegisterMessage(CGameNotifications_DeleteSession_Response)

CGameNotifications_UpdateSession_Request = _reflection.GeneratedProtocolMessageType('CGameNotifications_UpdateSession_Request', (_message.Message,), {
  'DESCRIPTOR' : _CGAMENOTIFICATIONS_UPDATESESSION_REQUEST,
  '__module__' : 'steammessages_gamenotifications_pb2'
  # @@protoc_insertion_point(class_scope:CGameNotifications_UpdateSession_Request)
  })
_sym_db.RegisterMessage(CGameNotifications_UpdateSession_Request)

CGameNotifications_UpdateSession_Response = _reflection.GeneratedProtocolMessageType('CGameNotifications_UpdateSession_Response', (_message.Message,), {
  'DESCRIPTOR' : _CGAMENOTIFICATIONS_UPDATESESSION_RESPONSE,
  '__module__' : 'steammessages_gamenotifications_pb2'
  # @@protoc_insertion_point(class_scope:CGameNotifications_UpdateSession_Response)
  })
_sym_db.RegisterMessage(CGameNotifications_UpdateSession_Response)

CGameNotifications_EnumerateSessions_Request = _reflection.GeneratedProtocolMessageType('CGameNotifications_EnumerateSessions_Request', (_message.Message,), {
  'DESCRIPTOR' : _CGAMENOTIFICATIONS_ENUMERATESESSIONS_REQUEST,
  '__module__' : 'steammessages_gamenotifications_pb2'
  # @@protoc_insertion_point(class_scope:CGameNotifications_EnumerateSessions_Request)
  })
_sym_db.RegisterMessage(CGameNotifications_EnumerateSessions_Request)

CGameNotifications_Session = _reflection.GeneratedProtocolMessageType('CGameNotifications_Session', (_message.Message,), {
  'DESCRIPTOR' : _CGAMENOTIFICATIONS_SESSION,
  '__module__' : 'steammessages_gamenotifications_pb2'
  # @@protoc_insertion_point(class_scope:CGameNotifications_Session)
  })
_sym_db.RegisterMessage(CGameNotifications_Session)

CGameNotifications_EnumerateSessions_Response = _reflection.GeneratedProtocolMessageType('CGameNotifications_EnumerateSessions_Response', (_message.Message,), {
  'DESCRIPTOR' : _CGAMENOTIFICATIONS_ENUMERATESESSIONS_RESPONSE,
  '__module__' : 'steammessages_gamenotifications_pb2'
  # @@protoc_insertion_point(class_scope:CGameNotifications_EnumerateSessions_Response)
  })
_sym_db.RegisterMessage(CGameNotifications_EnumerateSessions_Response)

CGameNotifications_GetSessionDetails_Request = _reflection.GeneratedProtocolMessageType('CGameNotifications_GetSessionDetails_Request', (_message.Message,), {

  'RequestedSession' : _reflection.GeneratedProtocolMessageType('RequestedSession', (_message.Message,), {
    'DESCRIPTOR' : _CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST_REQUESTEDSESSION,
    '__module__' : 'steammessages_gamenotifications_pb2'
    # @@protoc_insertion_point(class_scope:CGameNotifications_GetSessionDetails_Request.RequestedSession)
    })
  ,
  'DESCRIPTOR' : _CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST,
  '__module__' : 'steammessages_gamenotifications_pb2'
  # @@protoc_insertion_point(class_scope:CGameNotifications_GetSessionDetails_Request)
  })
_sym_db.RegisterMessage(CGameNotifications_GetSessionDetails_Request)
_sym_db.RegisterMessage(CGameNotifications_GetSessionDetails_Request.RequestedSession)

CGameNotifications_GetSessionDetails_Response = _reflection.GeneratedProtocolMessageType('CGameNotifications_GetSessionDetails_Response', (_message.Message,), {
  'DESCRIPTOR' : _CGAMENOTIFICATIONS_GETSESSIONDETAILS_RESPONSE,
  '__module__' : 'steammessages_gamenotifications_pb2'
  # @@protoc_insertion_point(class_scope:CGameNotifications_GetSessionDetails_Response)
  })
_sym_db.RegisterMessage(CGameNotifications_GetSessionDetails_Response)

GameNotificationSettings = _reflection.GeneratedProtocolMessageType('GameNotificationSettings', (_message.Message,), {
  'DESCRIPTOR' : _GAMENOTIFICATIONSETTINGS,
  '__module__' : 'steammessages_gamenotifications_pb2'
  # @@protoc_insertion_point(class_scope:GameNotificationSettings)
  })
_sym_db.RegisterMessage(GameNotificationSettings)

CGameNotifications_UpdateNotificationSettings_Request = _reflection.GeneratedProtocolMessageType('CGameNotifications_UpdateNotificationSettings_Request', (_message.Message,), {
  'DESCRIPTOR' : _CGAMENOTIFICATIONS_UPDATENOTIFICATIONSETTINGS_REQUEST,
  '__module__' : 'steammessages_gamenotifications_pb2'
  # @@protoc_insertion_point(class_scope:CGameNotifications_UpdateNotificationSettings_Request)
  })
_sym_db.RegisterMessage(CGameNotifications_UpdateNotificationSettings_Request)

CGameNotifications_UpdateNotificationSettings_Response = _reflection.GeneratedProtocolMessageType('CGameNotifications_UpdateNotificationSettings_Response', (_message.Message,), {
  'DESCRIPTOR' : _CGAMENOTIFICATIONS_UPDATENOTIFICATIONSETTINGS_RESPONSE,
  '__module__' : 'steammessages_gamenotifications_pb2'
  # @@protoc_insertion_point(class_scope:CGameNotifications_UpdateNotificationSettings_Response)
  })
_sym_db.RegisterMessage(CGameNotifications_UpdateNotificationSettings_Response)

CGameNotifications_OnNotificationsRequested_Notification = _reflection.GeneratedProtocolMessageType('CGameNotifications_OnNotificationsRequested_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CGAMENOTIFICATIONS_ONNOTIFICATIONSREQUESTED_NOTIFICATION,
  '__module__' : 'steammessages_gamenotifications_pb2'
  # @@protoc_insertion_point(class_scope:CGameNotifications_OnNotificationsRequested_Notification)
  })
_sym_db.RegisterMessage(CGameNotifications_OnNotificationsRequested_Notification)

CGameNotifications_OnUserStatusChanged_Notification = _reflection.GeneratedProtocolMessageType('CGameNotifications_OnUserStatusChanged_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CGAMENOTIFICATIONS_ONUSERSTATUSCHANGED_NOTIFICATION,
  '__module__' : 'steammessages_gamenotifications_pb2'
  # @@protoc_insertion_point(class_scope:CGameNotifications_OnUserStatusChanged_Notification)
  })
_sym_db.RegisterMessage(CGameNotifications_OnUserStatusChanged_Notification)


DESCRIPTOR._options = None
_CGAMENOTIFICATIONS_VARIABLE.fields_by_name['key']._options = None
_CGAMENOTIFICATIONS_VARIABLE.fields_by_name['value']._options = None
_CGAMENOTIFICATIONS_LOCALIZEDTEXT.fields_by_name['token']._options = None
_CGAMENOTIFICATIONS_LOCALIZEDTEXT.fields_by_name['variables']._options = None
_CGAMENOTIFICATIONS_LOCALIZEDTEXT.fields_by_name['rendered_text']._options = None
_CGAMENOTIFICATIONS_USERSTATUS.fields_by_name['steamid']._options = None
_CGAMENOTIFICATIONS_USERSTATUS.fields_by_name['state']._options = None
_CGAMENOTIFICATIONS_USERSTATUS.fields_by_name['title']._options = None
_CGAMENOTIFICATIONS_USERSTATUS.fields_by_name['message']._options = None
_CGAMENOTIFICATIONS_CREATESESSION_REQUEST.fields_by_name['appid']._options = None
_CGAMENOTIFICATIONS_CREATESESSION_REQUEST.fields_by_name['context']._options = None
_CGAMENOTIFICATIONS_CREATESESSION_REQUEST.fields_by_name['title']._options = None
_CGAMENOTIFICATIONS_CREATESESSION_REQUEST.fields_by_name['users']._options = None
_CGAMENOTIFICATIONS_CREATESESSION_REQUEST.fields_by_name['steamid']._options = None
_CGAMENOTIFICATIONS_CREATESESSION_RESPONSE.fields_by_name['sessionid']._options = None
_CGAMENOTIFICATIONS_DELETESESSION_REQUEST.fields_by_name['sessionid']._options = None
_CGAMENOTIFICATIONS_DELETESESSION_REQUEST.fields_by_name['appid']._options = None
_CGAMENOTIFICATIONS_DELETESESSION_REQUEST.fields_by_name['steamid']._options = None
_CGAMENOTIFICATIONS_UPDATESESSION_REQUEST.fields_by_name['sessionid']._options = None
_CGAMENOTIFICATIONS_UPDATESESSION_REQUEST.fields_by_name['appid']._options = None
_CGAMENOTIFICATIONS_UPDATESESSION_REQUEST.fields_by_name['title']._options = None
_CGAMENOTIFICATIONS_UPDATESESSION_REQUEST.fields_by_name['users']._options = None
_CGAMENOTIFICATIONS_UPDATESESSION_REQUEST.fields_by_name['steamid']._options = None
_CGAMENOTIFICATIONS_ENUMERATESESSIONS_REQUEST.fields_by_name['appid']._options = None
_CGAMENOTIFICATIONS_ENUMERATESESSIONS_REQUEST.fields_by_name['include_all_user_messages']._options = None
_CGAMENOTIFICATIONS_ENUMERATESESSIONS_REQUEST.fields_by_name['include_auth_user_message']._options = None
_CGAMENOTIFICATIONS_ENUMERATESESSIONS_REQUEST.fields_by_name['language']._options = None
_CGAMENOTIFICATIONS_SESSION.fields_by_name['sessionid']._options = None
_CGAMENOTIFICATIONS_SESSION.fields_by_name['appid']._options = None
_CGAMENOTIFICATIONS_SESSION.fields_by_name['context']._options = None
_CGAMENOTIFICATIONS_SESSION.fields_by_name['title']._options = None
_CGAMENOTIFICATIONS_SESSION.fields_by_name['time_created']._options = None
_CGAMENOTIFICATIONS_SESSION.fields_by_name['time_updated']._options = None
_CGAMENOTIFICATIONS_SESSION.fields_by_name['user_status']._options = None
_CGAMENOTIFICATIONS_ENUMERATESESSIONS_RESPONSE.fields_by_name['sessions']._options = None
_CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST_REQUESTEDSESSION.fields_by_name['sessionid']._options = None
_CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST_REQUESTEDSESSION.fields_by_name['include_auth_user_message']._options = None
_CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST.fields_by_name['appid']._options = None
_CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST.fields_by_name['language']._options = None
_CGAMENOTIFICATIONS_GETSESSIONDETAILS_RESPONSE.fields_by_name['sessions']._options = None
_GAMENOTIFICATIONSETTINGS.fields_by_name['appid']._options = None
_GAMENOTIFICATIONSETTINGS.fields_by_name['allow_notifications']._options = None
_CGAMENOTIFICATIONS_ONNOTIFICATIONSREQUESTED_NOTIFICATION.fields_by_name['steamid']._options = None
_CGAMENOTIFICATIONS_ONNOTIFICATIONSREQUESTED_NOTIFICATION.fields_by_name['appid']._options = None
_CGAMENOTIFICATIONS_ONUSERSTATUSCHANGED_NOTIFICATION.fields_by_name['steamid']._options = None
_CGAMENOTIFICATIONS_ONUSERSTATUSCHANGED_NOTIFICATION.fields_by_name['sessionid']._options = None
_CGAMENOTIFICATIONS_ONUSERSTATUSCHANGED_NOTIFICATION.fields_by_name['appid']._options = None
_CGAMENOTIFICATIONS_ONUSERSTATUSCHANGED_NOTIFICATION.fields_by_name['status']._options = None
_CGAMENOTIFICATIONS_ONUSERSTATUSCHANGED_NOTIFICATION.fields_by_name['removed']._options = None

_GAMENOTIFICATIONS = _descriptor.ServiceDescriptor(
  name='GameNotifications',
  full_name='GameNotifications',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030LA service for functions related to the asyncronous game notification server.',
  create_key=_descriptor._internal_create_key,
  serialized_start=6086,
  serialized_end=7148,
  methods=[
  _descriptor.MethodDescriptor(
    name='UserCreateSession',
    full_name='GameNotifications.UserCreateSession',
    index=0,
    containing_service=None,
    input_type=_CGAMENOTIFICATIONS_CREATESESSION_REQUEST,
    output_type=_CGAMENOTIFICATIONS_CREATESESSION_RESPONSE,
    serialized_options=b'\202\265\030\035Creates an async game session',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UserDeleteSession',
    full_name='GameNotifications.UserDeleteSession',
    index=1,
    containing_service=None,
    input_type=_CGAMENOTIFICATIONS_DELETESESSION_REQUEST,
    output_type=_CGAMENOTIFICATIONS_DELETESESSION_RESPONSE,
    serialized_options=b'\202\265\030\035Deletes an async game session',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UserUpdateSession',
    full_name='GameNotifications.UserUpdateSession',
    index=2,
    containing_service=None,
    input_type=_CGAMENOTIFICATIONS_UPDATESESSION_REQUEST,
    output_type=_CGAMENOTIFICATIONS_UPDATESESSION_RESPONSE,
    serialized_options=b'\202\265\030\035Updates an async game session',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EnumerateSessions',
    full_name='GameNotifications.EnumerateSessions',
    index=3,
    containing_service=None,
    input_type=_CGAMENOTIFICATIONS_ENUMERATESESSIONS_REQUEST,
    output_type=_CGAMENOTIFICATIONS_ENUMERATESESSIONS_RESPONSE,
    serialized_options=b'\202\265\030\034Enumerates a user\'s sessions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSessionDetails',
    full_name='GameNotifications.GetSessionDetails',
    index=4,
    containing_service=None,
    input_type=_CGAMENOTIFICATIONS_GETSESSIONDETAILS_REQUEST,
    output_type=_CGAMENOTIFICATIONS_GETSESSIONDETAILS_RESPONSE,
    serialized_options=b'\202\265\030&Get the details for a specific session',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateNotificationSettings',
    full_name='GameNotifications.UpdateNotificationSettings',
    index=5,
    containing_service=None,
    input_type=_CGAMENOTIFICATIONS_UPDATENOTIFICATIONSETTINGS_REQUEST,
    output_type=_CGAMENOTIFICATIONS_UPDATENOTIFICATIONSETTINGS_RESPONSE,
    serialized_options=b'\202\265\030CUpdates whether a user allows game notifications for a specific app',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_GAMENOTIFICATIONS)

DESCRIPTOR.services_by_name['GameNotifications'] = _GAMENOTIFICATIONS


_GAMENOTIFICATIONSCLIENT = _descriptor.ServiceDescriptor(
  name='GameNotificationsClient',
  full_name='GameNotificationsClient',
  file=DESCRIPTOR,
  index=1,
  serialized_options=b'\202\265\030\024Client notifications\300\265\030\002',
  create_key=_descriptor._internal_create_key,
  serialized_start=7151,
  serialized_end=7502,
  methods=[
  _descriptor.MethodDescriptor(
    name='OnNotificationsRequested',
    full_name='GameNotificationsClient.OnNotificationsRequested',
    index=0,
    containing_service=None,
    input_type=_CGAMENOTIFICATIONS_ONNOTIFICATIONSREQUESTED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030-Requests that the user opt into notifications',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnUserStatusChanged',
    full_name='GameNotificationsClient.OnUserStatusChanged',
    index=1,
    containing_service=None,
    input_type=_CGAMENOTIFICATIONS_ONUSERSTATUSCHANGED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030/Notification that the user\'s status has changed',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_GAMENOTIFICATIONSCLIENT)

DESCRIPTOR.services_by_name['GameNotificationsClient'] = _GAMENOTIFICATIONSCLIENT

GameNotifications = service_reflection.GeneratedServiceType('GameNotifications', (_service.Service,), dict(
  DESCRIPTOR = _GAMENOTIFICATIONS,
  __module__ = 'steammessages_gamenotifications_pb2'
  ))

GameNotifications_Stub = service_reflection.GeneratedServiceStubType('GameNotifications_Stub', (GameNotifications,), dict(
  DESCRIPTOR = _GAMENOTIFICATIONS,
  __module__ = 'steammessages_gamenotifications_pb2'
  ))


GameNotificationsClient = service_reflection.GeneratedServiceType('GameNotificationsClient', (_service.Service,), dict(
  DESCRIPTOR = _GAMENOTIFICATIONSCLIENT,
  __module__ = 'steammessages_gamenotifications_pb2'
  ))

GameNotificationsClient_Stub = service_reflection.GeneratedServiceStubType('GameNotificationsClient_Stub', (GameNotificationsClient,), dict(
  DESCRIPTOR = _GAMENOTIFICATIONSCLIENT,
  __module__ = 'steammessages_gamenotifications_pb2'
  ))


# @@protoc_insertion_point(module_scope)
